@@ -5,6 +5,7 @@ use warnings;
 
 # External dependencies.
 use Carp;
+use Try::Tiny;
 
 # Internal dependencies.
 use App::GitHooks::Constants qw( :HOOK_EXIT_CODES :PLUGIN_RETURN_CODES );
@@ -17,11 +18,11 @@ App::GitHooks::Hook - Base class for all git hook handlers.
 
 =head1 VERSION
 
-Version 1.7.1
+Version 1.7.2
 
 =cut
 
-our $VERSION = '1.7.1';
+our $VERSION = '1.7.2';
 
 
 =head1 METHODS
@@ -42,6 +43,12 @@ Arguments:
 
 An L<App::GitHooks> object.
 
+=item * stdin I<(optional)>
+
+An arrayref of lines retrieved from SDTIN.
+
+See for example the C<pre-push> hook for uses of this argument.
+
 =back
 
 =cut
@@ -50,6 +57,7 @@ sub run
 {
 	my ( $class, %args ) = @_;
 	my $app = $args{'app'};
+	my $stdin = $args{'stdin'};
 
 	# Find all the plugins that are applicable for this hook.
 	my $plugins = $app->get_hook_plugins( $app->get_hook_name() );
@@ -64,9 +72,24 @@ sub run
 		my $method = 'run_' . $app->get_hook_name();
 		$method =~ s/-/_/g;
 
-		my $return_code = $plugin->$method(
-			app => $app,
-		);
+		# Run the plugin method corresponding to this hook.
+		# If the plugin throws an exception, print the error message and consider
+		# the return code to be a failure.
+		my $return_code = try
+		{
+			return $plugin->$method(
+				app   => $app,
+				stdin => $stdin,
+			);
+		}
+		catch
+		{
+			chomp( $_ );
+			my $failure_character = $app->get_failure_character();
+			print $app->color( 'red', "$failure_character $_\n" );
+			return $PLUGIN_RETURN_FAILED;
+		};
+
 		$has_errors = 1
 			if $return_code == $PLUGIN_RETURN_FAILED;
 	}
